from SOAPpy import WSDL
server = WSDL.Proxy('/home/warneg/src/google/googleapi/GoogleSearch.wsdl')
key = "6k0oDPZQFHL0zpjy6ZO6ufUVFKBgvqTo"

results = server.doGoogleSearch(key, 'warnes', 0, 10, False, "", 
                                False, "", "utf-8", "utf-8") 


for i in range(len(results.resultElements)):
  res = results.resultElements[i]
  print '%d: %s --> %s' % ( i, res.title, res.URL )



"""
Check handing of unicode.
"""

import sys
sys.path.insert(1, "..")
from SOAPpy import *

# Uncomment to see outgoing HTTP headers and SOAP and incoming 
#Config.debug = 1
#Config.dumpHeadersIn = 1
#Config.dumpSOAPIn = 1
#Config.dumpSOAPOut = 1

# ask for returned SOAP responses to be converted to basic python types
Config.simplify_objects = 1

#Config.BuildWithNoType = 1
#Config.BuildWithNoNamespacePrefix = 1


def headers():
  '''Return a soap header containing all the needed information.'''
  hd = Types.headerType()
  hd.useragent = Types.stringType("foo")
  return hd

server = SOAPProxy("http://localhost:9900/",header=headers())

adgroupid = 197497504
keyword1 = { 'status': 'Moderate',
		'adGroupId': 197497504,
		'destinationURL': None,
		'language': '',
		'text': 'does not work',
		'negative': bool(0),
		'maxCpc': 50000,
		'type': 'Keyword',
		'id': 1 }
keyword2 = { 'status': 'Moderate',
		'adGroupId': 197497504,
		'destinationURL': None,
		'language': '',
		'text': 'yes it does not',
		'negative': bool(0),
		'maxCpc': 50000,
		'type': 'Keyword',
		'id': 2 }
keylist = [keyword1, keyword2]

# Check that the data goes through properly

retval = server.echo_simple(adgroupid, keylist)

kw1 = retval[1][0]
kw2 = retval[1][1]

assert(retval[0] == adgroupid)

for key in kw1.keys():
  assert(kw1[key]==keyword1[key])

for key in kw2.keys():
  assert(kw2[key]==keyword2[key])

# Check that the header is preserved
retval = server.echo_header((adgroupid, keylist))

assert(retval[1].has_key('useragent'))
assert(retval[1]['useragent'] == 'foo')

server.quit()

print "Success!"




import sys
sys.path.insert(1, "..")
from SOAPpy import *

detailed_fault = \
"""
<?xml version="1.0" encoding="UTF-8"?>
<SOAP-ENV:Envelope xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:SOAP-ENC="http://schemas.xmlsoap.org/soap/encoding/" xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" SOAP-ENV:encodingStyle="http://schemas.microsoft.com/soap/encoding/clr/1.0 http://schemas.xmlsoap.org/soap/encoding/" xmlns:a1="http://schemas.microsoft.com/clr/ns/System.Runtime.Serialization.Formatters">
<SOAP-ENV:Body>
<SOAP-ENV:Fault id="ref-1">

<faultcode>soapenv:Server.generalException</faultcode>
<faultstring>Exception thrown on Server</faultstring>

<detail>
<loginFailureFault href="#id0"/>
<exceptionName xsi:type="xsd:string">...</exceptionName>
</detail>

</SOAP-ENV:Fault>

<multiRef id="id0">
<description xsi:type="xsd:string">Login failure (504):Unknown User</description>
<module xsi:type="xsd:string"> ... </module>
<timestamp xsi:type="xsd:string">...</timestamp>
<faultcode xsi:type="xsd:string"> ...</faultcode>
<parameter xsi:type="xsd:string"> ... </parameter>
</multiRef>

</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
"""

z = parseSOAPRPC(detailed_fault.strip() )
assert(z.__class__==faultType)
assert(z.faultstring=="Exception thrown on Server")
assert(z.detail.loginFailureFault.description=='Login failure (504):Unknown User')
print "Success"
